#coding=UTF-8

#fakeClipboardAnouncement.py
#A simple NVDA Global Plugin
#Written by Peter Vagner <peter.v@datagate.sk>

# 2011/08/25: Does not anounce the keys in the console windows

# 2011/08/20: initial version

# When pressing ctrl+a, ctrl+y, ctrl+z, ctrl+x, ctrl+c, ctrl+v NVDA will say the message predefined in the dictionary below and then send the gesture back to the active app.

# We initialize translation support

import globalPluginHandler
import ui
import api
import inputCore
import scriptHandler
import globalVars
import os
import languageHandler
import gettext
import addonHandler
addonHandler.initTranslation()
messagesDict={
	"control+a":_("Select All"),
	"control+y":_("REDo"),
	"control+z":_("UnDo"),
	"control+x":_("Cut"),
	"control+c":_("Copy"),
	"control+v":_("Paste")
}


class GlobalPlugin(globalPluginHandler.GlobalPlugin):
	"""
This is our plugin class, that must be present in order for plugin to work. It must be named exactly as shown above, otherwise the plugin will not be recognized by NVDA.
"""

	def script_fakeClipboardAnouncement(self,gesture):
		gesture.send()
		focus = api.getFocusObject()
		if not focus:
			return 
		if focus.windowClassName == 'ConsoleWindowClass':
			return
		globalMapScripts = []
		globalMaps = [inputCore.manager.userGestureMap, inputCore.manager.localeGestureMap]
		for globalMap in globalMaps:
			for identifier in gesture.identifiers:
				globalMapScripts.extend(globalMap.getScriptsForGesture(identifier))
		treeInterceptor = focus.treeInterceptor
		if treeInterceptor and treeInterceptor.isReady:
			func = scriptHandler._getObjScript(treeInterceptor, gesture, globalMapScripts)
			if func and (not treeInterceptor.passThrough or getattr(func,"ignoreTreeInterceptorPassThrough",False)):
				func(treeInterceptor)
				return
		ui.message(messagesDict["+".join(gesture.modifierNames)+"+"+gesture.mainKeyName])


#: Now defining a dictionary with key bindings for this plugin
	__gestures = {
		"kb:Control+x": "fakeClipboardAnouncement", #will execute our script on pressing the designated key
		"kb:Control+c": "fakeClipboardAnouncement", #will execute our script on pressing the designated key
		"kb:Control+v": "fakeClipboardAnouncement", #will execute our script on pressing the designated key
		"kb:Control+a": "fakeClipboardAnouncement", #will execute our script on pressing the designated key
		"kb:Control+y": "fakeClipboardAnouncement", #will execute our script on pressing the designated key
		"kb:Control+z": "fakeClipboardAnouncement", #will execute our script on pressing the designated key
	}